pub struct AbstractState {
pub vars: HashMap<String, IntervalDomain>,
}Expand description
An abstract state: a map from variable name to interval abstract value.
Fields
vars: HashMap<String, IntervalDomain>Variable name → interval abstract value
Implementations
Sourceimpl AbstractState
impl AbstractState
Sourcepub fn get(&self, var: &str) -> IntervalDomain
pub fn get(&self, var: &str) -> IntervalDomain
Look up the abstract value of a variable (top if unknown).
Sourcepub fn set(&mut self, var: impl Into<String>, val: IntervalDomain)
pub fn set(&mut self, var: impl Into<String>, val: IntervalDomain)
Set the abstract value of a variable.