RewriteSystem

Struct RewriteSystem 

pub struct RewriteSystem<T: Clone + Eq> {
    pub rules: Vec<RewriteRule<T>>,
    pub strategy: RewriteStrategy,
}
A term rewriting system with a collection of rules and a reduction strategy.

Fields

rules: Vec<RewriteRule<T>>

The set of rewrite rules.

strategy: RewriteStrategy

The reduction strategy to use.

Implementations

Source

impl<T: Clone + Eq> RewriteSystem<T>

pub fn new(strategy: RewriteStrategy) -> Self

Creates a new rewrite system with the given strategy.

pub fn add_rule(&mut self, rule: RewriteRule<T>)

Adds a rule to the system.