pub struct Effect {
pub name: String,
pub operations: Vec<String>,
}Expand description
An algebraic effect with a name and a list of operations.
Fields
name: StringThe name of the effect.
operations: Vec<String>The operation names of this effect.
Implementations
Sourceimpl Effect
impl Effect
Sourcepub fn is_algebraic(&self) -> bool
pub fn is_algebraic(&self) -> bool
Every algebraic effect is algebraic in the sense of Plotkin and Power.
Sourcepub fn free_monad(&self) -> String
pub fn free_monad(&self) -> String
The free monad generated by the functor of operations.