HandlerType

Struct HandlerType 

pub struct HandlerType {
    pub input_type: String,
    pub output_type: String,
    pub effect_row: String,
}
The type of a handler: maps input type with effect row to output type.

Fields

input_type: String

The input computation type.

output_type: String

The output computation type.

effect_row: String

The effect row being handled.

Implementations

Source

impl HandlerType

pub fn new( input_type: impl Into<String>, output_type: impl Into<String>, effect_row: impl Into<String>, ) -> Self

Create a new HandlerType.

pub fn handles_effect(&self, effect: &str) -> bool

Check whether this handler type handles the given effect.

pub fn continuation_type(&self) -> String

The continuation type within the handler.