pub fn arr_ext_sort_stable_ty() -> ExprExpand description
Array.sort_stable : ∀ {α n}, [Ord α] → Array α n → Prop
Stability of merge sort: elements with equal keys retain their original relative order. A stable sort preserves the original ordering for equal elements.