pub struct RNAMFEFolder {
pub unpaired_penalty: f64,
pub pair_bonus: f64,
}Expand description
An RNA secondary structure folder using the Nussinov maximum base-pair algorithm as a proxy for minimum free energy (MFE) folding.
Fields
unpaired_penalty: f64Penalty per unpaired base (negative = energetically unfavourable).
pair_bonus: f64Energy bonus per base pair.
Implementations