Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

BoolAlgebra
Boolean algebra structure witnessing the laws of a Boolean algebra.
BoolLattice
Boolean lattice structure: (Bool, OR=join, AND=meet, false=bot, true=top).
DecidablePred
Decidable predicate: a predicate P: T -> Bool computable at runtime.
SATInstance
SAT instance: a propositional formula in conjunctive normal form.
TruthTable
A complete truth table for a 2-input boolean function.
TruthTableEntry
A truth table entry for a 2-input boolean function.
XorMonoid
XOR monoid structure: (Bool, XOR, false) is a commutative group.

Enums

BoolExpr
A boolean expression tree used to represent propositional formulas.
Kleene3Val
A simple Kleene three-valued logic evaluator.