UnicodeBlocks

Struct UnicodeBlocks 

pub struct UnicodeBlocks;
Named Unicode character blocks relevant to OxiLean.

Implementations

Source

impl UnicodeBlocks

pub const BASIC_LATIN: CharRange

Basic Latin (ASCII range).

pub const LATIN1_SUPPLEMENT: CharRange

Latin-1 Supplement.

pub const GREEK: CharRange

Greek and Coptic.

pub const MATH_OPERATORS: CharRange

Mathematical Operators.

pub const SUPP_MATH_OPERATORS: CharRange

Supplemental Mathematical Operators.

pub const MATH_ALPHANUMERIC: CharRange

Mathematical Alphanumeric Symbols.

pub const LETTERLIKE: CharRange

Letterlike Symbols.

pub const ARROWS: CharRange

Arrows.

pub fn is_math_operator(cp: u32) -> bool

Check if a code point is in the mathematical operators range.

pub fn is_greek(cp: u32) -> bool

Check if a code point is in the Greek range.

pub fn is_arrow(cp: u32) -> bool

Check if a code point is in the arrows range.