pub struct CoinductiveProof<S: Clone + Eq> {
pub relation: BisimulationRelation<S>,
pub progress: Vec<String>,
}Expand description
A completed coinductive proof certificate.
Contains the bisimulation relation that was found to be valid, plus a trace of the progress steps made during the proof search.
Fields
relation: BisimulationRelation<S>progress: Vec<String>Trait Implementations