pub fn build_complex_env(env: &mut Environment) -> Result<(), String>Expand description
Build the complex number environment, registering all axioms and theorems.
pub fn build_complex_env(env: &mut Environment) -> Result<(), String>Build the complex number environment, registering all axioms and theorems.