Triangle

Struct Triangle 

pub struct Triangle {
    pub a: usize,
    pub b: usize,
    pub c: usize,
}
A triangle specified by vertex indices into a point array

Fields

a: usizeb: usizec: usize

Implementations

Source

impl Triangle

pub fn new(a: usize, b: usize, c: usize) -> Self

pub fn contains_vertex(&self, i: usize) -> bool

Check if index i is one of the vertices