ConTinuousFunction

Struct ConTinuousFunction 

pub struct ConTinuousFunction {
    pub is_uniformly_continuous: bool,
}
A constructive continuous function (on the Baire space or unit interval).

Fields

is_uniformly_continuous: bool

Whether the function is (provably) uniformly continuous.

Implementations

Source

impl ConTinuousFunction

pub fn new(is_uniformly_continuous: bool) -> Self

Create a new ConTinuousFunction.

pub fn by_fan_theorem(&self) -> bool

The Fan Theorem implies that every function on the Cantor space [2^ω] is uniformly continuous.

pub fn kleene_brouwer(&self) -> &'static str

The Kleene–Brouwer ordering on well-founded trees is used to construct continuous functions from spreads.