ConstructiveReal

Struct ConstructiveReal 

pub struct ConstructiveReal {
    pub approx: Vec<i64>,
    pub max_prec: usize,
}
A constructive real number represented as a function from precision k to a dyadic rational m * 2^{-k} such that |x - m*2^{-k}| < 2^{-k}.

Fields

approx: Vec<i64>

approx(k) gives the numerator m such that the approximation is m * 2^{-k}.

max_prec: usize

Implementations

Source

impl ConstructiveReal

pub fn from_rational(p: i64, q: i64, max_prec: usize) -> Self

Construct a ConstructiveReal from a rational p/q.

pub fn add(&self, other: &ConstructiveReal) -> ConstructiveReal

Add two constructive reals.

pub fn get_approx(&self, k: usize) -> (i64, usize)

Get rational approximation at precision k: returns (m, k) meaning m * 2^{-k}.

pub fn approx_eq(&self, other: &ConstructiveReal, k: usize) -> bool

Check if |self - other| < 2^{-k} (approximate equality at precision k).