pub struct HeylandAlgebra {
pub carrier: Vec<String>,
}Expand description
A Heyting algebra: a lattice with a relative pseudo-complement (→).
Fields
carrier: Vec<String>The carrier elements (represented as strings).
Implementations
Sourceimpl HeylandAlgebra
impl HeylandAlgebra
Sourcepub fn is_heyting_algebra(&self) -> bool
pub fn is_heyting_algebra(&self) -> bool
Check that this carrier can form a Heyting algebra (non-empty and closed).
Sourcepub fn intuitionistic_propositional_logic(&self) -> &'static str
pub fn intuitionistic_propositional_logic(&self) -> &'static str
Heyting algebras provide the algebraic semantics for intuitionistic propositional logic (IPL / IPC).