ideal_functionality_ty

Function ideal_functionality_ty 

pub fn ideal_functionality_ty() -> Expr
IdealFunctionality : Type

An ideal functionality F in the UC framework: a trusted third party that receives inputs from all parties and delivers outputs. Security is defined by emulating this ideal world in the real world.