pub fn two_phase_commit(
participants: &mut Vec<TwoPCParticipant>,
) -> TwoPCOutcomeExpand description
Run a full 2PC protocol.
Returns Committed if all participants vote yes, Aborted otherwise.
pub fn two_phase_commit(
participants: &mut Vec<TwoPCParticipant>,
) -> TwoPCOutcomeRun a full 2PC protocol.
Returns Committed if all participants vote yes, Aborted otherwise.