Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

EnvBuilder
A thin wrapper around Environment providing convenience methods for registering axioms and definitions during standard library initialisation.