HeterogeneousEq

Struct HeterogeneousEq 

pub struct HeterogeneousEq<A, B> {
    pub left: A,
    pub right: B,
    pub justification: &'static str,
}
A heterogeneous equality witness between values of potentially different types.

Fields

left: A

The left-hand value.

right: B

The right-hand value.

justification: &'static str

A human-readable justification.

Implementations

Source

impl<A, B> HeterogeneousEq<A, B>

pub fn new(left: A, right: B, justification: &'static str) -> Self

Construct a heterogeneous equality witness.

Source

impl<A: Clone + PartialEq> HeterogeneousEq<A, A>

pub fn is_homogeneous_eq(&self) -> bool

When both sides have the same type, check propositional equality.

pub fn to_homogeneous(&self) -> Option<EqualityWitness<A>>

Extract a homogeneous EqualityWitness if values are equal.