pub fn modules_for_phase(phase: BuildPhase) -> Vec<&'static StdModuleEntry>Expand description
Get all module entries for a specific build phase.
pub fn modules_for_phase(phase: BuildPhase) -> Vec<&'static StdModuleEntry>Get all module entries for a specific build phase.