fixed_point_semantics_ty

Function fixed_point_semantics_ty 

pub fn fixed_point_semantics_ty() -> Expr
FixedPointSemantics : (Type → Type) → Type → Prop

Kleene fixed-point: the least fixed point of a monotone endofunctor on a Scott domain, providing denotational semantics for recursive definitions.