Lens

Struct Lens 

pub struct Lens<S, A> { /* private fields */ }
A lawful lens focusing on field A inside structure S.

Implementations

Source

impl<S: 'static, A: 'static> Lens<S, A>

pub fn new( getter: impl Fn(&S) -> A + 'static, setter: impl Fn(A, S) -> S + 'static, ) -> Self

Create a lens from a getter and a setter.

pub fn view(&self, s: &S) -> A

Get the focused value.

pub fn set(&self, a: A, s: S) -> S

Set the focused value.

pub fn over(&self, f: impl Fn(A) -> A, s: S) -> S
where S: Clone,

Modify the focused value.