LensComposer

Struct LensComposer 

pub struct LensComposer;
LensComposer provides utilities for composing lenses and verifying laws.

Implementations

Source

impl LensComposer

pub fn compose<S, M, A>( outer: Lens<S, M>, inner: Lens<M, A>, ) -> impl Fn(&S) -> A
where S: Clone + 'static, M: Clone + 'static, A: Clone + 'static,

Compose two lenses: outer focuses on M inside S, inner focuses on A inside M.

pub fn check_get_set<S, A>(lens: &Lens<S, A>, s: S) -> bool
where S: Clone + PartialEq + 'static, A: Clone + 'static,

Check the GetSet law: set(get(s), s) == s.

pub fn check_set_get<S, A>(lens: &Lens<S, A>, a: A, s: S) -> bool
where S: Clone + 'static, A: Clone + PartialEq + 'static,

Check the SetGet law: get(set(a, s)) == a.

pub fn check_set_set<S, A>(lens: &Lens<S, A>, a1: A, a2: A, s: S) -> bool
where S: Clone + PartialEq + 'static, A: Clone + 'static,

Check the SetSet law: set(a2, set(a1, s)) == set(a2, s).