pub struct AssocMap<K, V> { /* private fields */ }Expand description
A simple association list map.
Provides O(n) lookup but is useful in contexts where the number of entries is small and allocation overhead should be minimal.
Implementations
Sourceimpl<K: PartialEq + Clone, V: Clone> AssocMap<K, V>
impl<K: PartialEq + Clone, V: Clone> AssocMap<K, V>
Sourcepub fn insert(&mut self, key: K, value: V)
pub fn insert(&mut self, key: K, value: V)
Insert a key-value pair, replacing any existing entry for that key.
Sourcepub fn contains_key(&self, key: &K) -> bool
pub fn contains_key(&self, key: &K) -> bool
Check if the map contains a key.
Sourcepub fn iter(&self) -> impl Iterator<Item = &(K, V)>
pub fn iter(&self) -> impl Iterator<Item = &(K, V)>
Iterate over key-value pairs in insertion order.