pub fn big_intersection<T: Eq + Hash + Clone, I: IntoIterator<Item = OxiHashSet<T>>>(
sets: I,
) -> OxiHashSet<T>Expand description
Compute the intersection of a collection of sets (empty input → empty set).
pub fn big_intersection<T: Eq + Hash + Clone, I: IntoIterator<Item = OxiHashSet<T>>>(
sets: I,
) -> OxiHashSet<T>Compute the intersection of a collection of sets (empty input → empty set).