pub fn difference_all<'a, T: Eq + Hash + Clone + 'a>(
a: &OxiHashSet<T>,
others: impl Iterator<Item = &'a OxiHashSet<T>>,
) -> OxiHashSet<T>Expand description
Return elements that appear in a but not in any set in others.
pub fn difference_all<'a, T: Eq + Hash + Clone + 'a>(
a: &OxiHashSet<T>,
others: impl Iterator<Item = &'a OxiHashSet<T>>,
) -> OxiHashSet<T>Return elements that appear in a but not in any set in others.