Capability

Struct Capability 

pub struct Capability {
    pub level: u32,
    pub description: String,
}
A capability token representing a permission level for IO operations.

Fields

level: u32

The permission level (higher = more privileged).

description: String

Human-readable description.

Implementations

Source

impl Capability

pub fn new(level: u32, description: impl Into<String>) -> Self

Create a new capability token.

pub fn null() -> Self

Null capability (no permissions).

pub fn read_only() -> Self

Read-only capability.

pub fn read_write() -> Self

Read-write capability.

pub fn full() -> Self

Full (root) capability.

pub fn is_sufficient_for(&self, required: u32) -> bool

Check if this capability is sufficient for the required level.

pub fn attenuate(&self, max_level: u32) -> Capability

Attenuate (reduce) the capability to a lower level.