SessionChannel

Struct SessionChannel 

pub struct SessionChannel { /* private fields */ }
A typed session channel enforcing a protocol.

Implementations

Source

impl SessionChannel

pub fn new(protocol: Vec<SessionAction>) -> Self

Create a channel with the given protocol.

pub fn send(&mut self, msg: impl Into<String>) -> Result<(), String>

Attempt to perform a send action.

Returns Ok(()) if the protocol expects a send at this point.

pub fn recv(&mut self) -> Result<Option<String>, String>

Attempt to perform a receive action.

Returns the next message if the protocol expects a receive.

pub fn is_complete(&self) -> bool

Check if the protocol has been fully followed.

pub fn remaining_steps(&self) -> usize

Number of steps remaining in the protocol.