pub enum BinarySession {
Send(String, Box<BinarySession>),
Recv(String, Box<BinarySession>),
Select(Vec<(String, BinarySession)>),
Offer(Vec<(String, BinarySession)>),
Rec(String, Box<BinarySession>),
Var(String),
End,
}Expand description
A session type in the binary session type system.
Variants
Send(String, Box<BinarySession>)
Send a value of type label and continue as next.
Recv(String, Box<BinarySession>)
Receive a value of type label and continue as next.
Select(Vec<(String, BinarySession)>)
Internal choice: select one of the offered branches.
Offer(Vec<(String, BinarySession)>)
External choice: offer a set of branches.
Rec(String, Box<BinarySession>)
Recursive session: μX.S where name is the recursion variable.
Var(String)
Session variable reference.
End
Completed session.