GuardedFix

Struct GuardedFix 

pub struct GuardedFix<A> { /* private fields */ }
A guarded recursive definition builder.

Implements Löb’s principle: if we can build A assuming we already have a ▶A (a “later” version), then we can produce A unconditionally.

Implementations

Source

impl<A: Clone + 'static> GuardedFix<A>

pub fn evaluate(step: impl Fn(Box<dyn Fn() -> A>) -> A) -> A

Create a guarded fixpoint by providing a step function.

The step function receives a thunk for the recursive call.

pub fn is_computed(&self) -> bool

Check if the cell has been forced.