Struct Heap
Source pub struct Heap {
pub map: HashMap<u64, u64>,
}
A simple heap: a finite partial map from addresses to values.
Map from address to value.
Create a singleton heap {addr ↦ val}.
Check if two heaps have disjoint domains.
Union of two disjoint heaps.
Size of the heap (number of mapped addresses).
Read a value from the heap.
Write a value to the heap (returns a new heap).
Check separating conjunction: h ⊨ P * Q.
Returns Some((h1, h2)) if h splits as h1 satisfying P and h2 satisfying Q.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The equivalence relation.
Reflexivity of the equivalence.
Symmetry: if self ~ other then other ~ self.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.