pub struct LinSequent {
pub formulas: Vec<LinFormula>,
}Expand description
A one-sided sequent: ⊢ Γ (a multiset of linear formulas).
Fields
formulas: Vec<LinFormula>Formulas in the succedent (all on the right in one-sided calculus).
Implementations
Sourceimpl LinSequent
impl LinSequent
Sourcepub fn new(formulas: Vec<LinFormula>) -> Self
pub fn new(formulas: Vec<LinFormula>) -> Self
Create a new sequent from a list of formulas.
Sourcepub fn tensor_components(&self) -> Option<(LinSequent, LinFormula, LinFormula)>
pub fn tensor_components(&self) -> Option<(LinSequent, LinFormula, LinFormula)>
Apply the tensor rule: split into two sub-sequents. Returns the two components if the sequent has the form ⊢ …, A ⊗ B, …
Sourcepub fn total_complexity(&self) -> usize
pub fn total_complexity(&self) -> usize
Total complexity of all formulas in the sequent.