pub struct PhaseSemantics {
pub monoid: String,
pub facts: Vec<String>,
}Expand description
Phase semantics: Girard’s completeness model for linear logic based on a commutative monoid with a set of facts closed under a Galois connection.
Fields
monoid: StringName of the underlying monoid.
facts: Vec<String>Names of the facts (elements of the monoid satisfying the facts predicate).
Implementations
Sourceimpl PhaseSemantics
impl PhaseSemantics
Sourcepub fn new(monoid: impl Into<String>, facts: Vec<String>) -> Self
pub fn new(monoid: impl Into<String>, facts: Vec<String>) -> Self
Create a new phase semantics structure.
Sourcepub fn interpret_formula(&self, formula: &str) -> String
pub fn interpret_formula(&self, formula: &str) -> String
Interpret a formula in the phase space.
Returns a string description of the interpretation (the “fact set” for that formula).
Sourcepub fn soundness(&self, formula: &str) -> bool
pub fn soundness(&self, formula: &str) -> bool
Soundness: every provable formula is valid in all phase spaces.
Sourcepub fn completeness_statement(&self) -> String
pub fn completeness_statement(&self) -> String
Completeness: every formula valid in all phase spaces is provable.