Quantales

Struct Quantales 

pub struct Quantales {
    pub quantale: String,
}
A quantale: a complete lattice with an associative binary operation that distributes over arbitrary joins. Quantales model substructural logics.

Fields

quantale: String

Name of the quantale.

Implementations

Source

impl Quantales

pub fn new(quantale: impl Into<String>) -> Self

Create a new quantale.

pub fn is_linear_category(&self) -> bool

Check if this quantale is a model of linear logic (a *-autonomous quantale).

pub fn star_autonomous(&self) -> String

Check if this is a *-autonomous (star-autonomous) category.

A *-autonomous category is a symmetric monoidal category with a dualizing object, giving models of classical linear logic (MLL).

pub fn free_star_autonomous(atoms: &[&str]) -> Self

The free *-autonomous category on a set of atoms.

pub fn phase_space_quantale(monoid: &str) -> Self

The phase space quantale over a monoid.

pub fn chu_construction(&self, k: &str) -> String

The Chu construction: a way to build *-autonomous categories.

pub fn dualizing_object(&self) -> String

The dualizing object (bottom element in MLL models).