BuchiAutomaton

Struct BuchiAutomaton 

pub struct BuchiAutomaton {
    pub num_states: usize,
    pub alphabet: Vec<String>,
    pub transitions: Vec<Vec<(HashSet<String>, usize)>>,
    pub initial_state: usize,
    pub accepting_states: HashSet<usize>,
}
A Büchi automaton: (Q, Σ, δ, q_0, F).

Fields

num_states: usize

Number of states.

alphabet: Vec<String>

Alphabet (atomic propositions as strings).

transitions: Vec<Vec<(HashSet<String>, usize)>>

Transition function: transitions[q] = list of (label_set, target) pairs.

initial_state: usize

Initial state.

accepting_states: HashSet<usize>

Set of accepting (Büchi) states.

Implementations

Source

impl BuchiAutomaton

pub fn new(n: usize) -> Self

Create a new Büchi automaton with n states.

pub fn add_accepting(&mut self, q: usize)

Mark state q as accepting.

pub fn add_transition(&mut self, q: usize, label: HashSet<String>, r: usize)

Add a transition from q to r on the given label set.

pub fn has_accepting_states(&self) -> bool

Returns true if the automaton has any accepting states.