Groupoid

Struct Groupoid 

pub struct Groupoid {
    pub name: String,
    pub object_space: String,
    pub morphism_space: String,
}
A (locally compact) groupoid G ⇒ G^{(0)}.

A groupoid is a small category in which every morphism is invertible. Special cases include groups (one object), equivalence relations, and transformation groupoids G ⋊ X.

Fields

name: String

Descriptive name of the groupoid.

object_space: String

Description of the object (unit) space G^{(0)}.

morphism_space: String

Description of the morphism (arrow) space G^{(1)}.

Implementations

Source

impl Groupoid

pub fn new(name: impl Into<String>) -> Self

Construct a groupoid with the given name.

pub fn is_group(&self) -> bool

A groupoid with a single object is a group.

pub fn is_equivalence_relation(&self) -> bool

A groupoid is an equivalence relation when there is at most one morphism between any two objects (i.e. the groupoid is a (0,1)-category).

Source

impl Groupoid

pub fn groupoid_cstar_algebra(&self) -> String

Constructs the reduced groupoid C*-algebra C*_r(G) of this groupoid.

Returns a description of the resulting C*-algebra.