HyperfiniteProb

Struct HyperfiniteProb 

pub struct HyperfiniteProb {
    pub size: usize,
}
A simplified Loeb probability space on a finite hyperfinite set {0, …, N-1}.

The internal probability of a set A is |A|/N. The Loeb probability is the standard part: st(|A|/N) = |A|/N for finite N.

Fields

size: usize

The “infinite” (but computationally finite) size N.

Implementations

Source

impl HyperfiniteProb

pub fn new(size: usize) -> Self

Create a hyperfinite probability space of size N.

pub fn internal_prob(&self, set: &[usize]) -> f64

Internal probability of a set given by a list of indices.

pub fn loeb_prob(&self, set: &[usize]) -> f64

Loeb probability = standard part of internal probability (same for finite sizes).

pub fn loeb_independent(&self, a: &[usize], b: &[usize]) -> bool

Check if two events are “independent” under Loeb measure.