Hyperreal

Struct Hyperreal 

pub struct Hyperreal {
    pub standard: f64,
    pub infinitesimal_part: f64,
    pub infinite_part: f64,
}
A hyperreal number with a standard part, an infinitesimal part, and an infinite part.

Fields

standard: f64infinitesimal_part: f64infinite_part: f64

Implementations

Source

impl Hyperreal

pub fn new(standard: f64, infinitesimal_part: f64, infinite_part: f64) -> Self

pub fn standard_part(&self) -> Option<f64>

The standard part (shadow) of a finite hyperreal.

pub fn is_finite(&self) -> bool

A hyperreal is finite if its infinite part is 0.

pub fn is_infinitesimal(&self) -> bool

A hyperreal is infinitesimal if both standard and infinite parts are 0.