pub struct InternalSet {
pub property: String,
}Expand description
An internal set, defined by an internal property string.
Fields
property: StringImplementations
Sourceimpl InternalSet
impl InternalSet
pub fn new(property: String) -> Self
Sourcepub fn is_internal(&self) -> bool
pub fn is_internal(&self) -> bool
All sets defined by first-order formulas are internal.
Sourcepub fn overflow_principle(&self) -> bool
pub fn overflow_principle(&self) -> bool
Overflow principle: if an internal set contains all standard naturals, it contains some non-standard natural.