Struct Interval
Source pub struct Interval {
pub lo: f64,
pub hi: f64,
}
A closed real interval [lo, hi] used for validated/verified computation.
Construct the interval [lo, hi]. Panics if lo > hi.
Construct a point interval [x, x].
Interval addition: [a,b] + [c,d] = [a+c, b+d].
Interval subtraction: [a,b] - [c,d] = [a-d, b-c].
Interval multiplication (all four products, take min/max).
Midpoint of the interval.
Check whether a real value is contained in [lo, hi].
Interval enclosure of sqrt (valid for non-negative intervals).
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The equivalence relation.
Reflexivity of the equivalence.
Symmetry: if self ~ other then other ~ self.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.