NewtonRaphsonSolver

Struct NewtonRaphsonSolver 

pub struct NewtonRaphsonSolver {
    pub tol: f64,
    pub max_iter: u32,
}
Newton–Raphson solver that also reports whether convergence was achieved.

Fields

tol: f64max_iter: u32

Implementations

Source

impl NewtonRaphsonSolver

pub fn new(tol: f64, max_iter: u32) -> Self

Create a new NewtonRaphsonSolver.

pub fn solve( &self, f: &dyn Fn(f64) -> f64, df: &dyn Fn(f64) -> f64, x: f64, ) -> (f64, bool)

Attempt to find a root of f starting from x0. Returns (root, converged).