pub struct DynamicProgramming;Expand description
A collection of classic dynamic programming algorithms.
Implementations
Sourceimpl DynamicProgramming
impl DynamicProgramming
Sourcepub fn knapsack(capacity: usize, weights: &[usize], values: &[usize]) -> usize
pub fn knapsack(capacity: usize, weights: &[usize], values: &[usize]) -> usize
0/1 knapsack: maximum value achievable with given capacity.
Sourcepub fn longest_common_subseq(s1: &[u8], s2: &[u8]) -> usize
pub fn longest_common_subseq(s1: &[u8], s2: &[u8]) -> usize
Length of the longest common subsequence of byte slices s1 and s2.
Sourcepub fn matrix_chain_order(dims: &[usize]) -> usize
pub fn matrix_chain_order(dims: &[usize]) -> usize
Minimum number of scalar multiplications to compute a chain of matrices.
dims has length n+1 where the i-th matrix is dims[i] × dims[i+1].