pub struct OptionCache<K: PartialEq, V> { /* private fields */ }Expand description
A simple cache mapping keys to optional computed values.
If a key is present and Some, the cached value is returned.
If a key is absent, the computation is run and cached.
Implementations
Sourceimpl<K: PartialEq, V: Clone> OptionCache<K, V>
impl<K: PartialEq, V: Clone> OptionCache<K, V>
Sourcepub fn get_or_insert_with(
&mut self,
key: K,
compute: impl FnOnce() -> Option<V>,
) -> Option<V>where
K: Clone,
pub fn get_or_insert_with(
&mut self,
key: K,
compute: impl FnOnce() -> Option<V>,
) -> Option<V>where
K: Clone,
Get or compute a value for key.
If the key is already cached, returns the cached value.
Otherwise runs compute and caches the result.
Sourcepub fn invalidate(&mut self, key: &K)
pub fn invalidate(&mut self, key: &K)
Invalidate (remove) an entry.