pub struct IntegralExtension {
pub base: String,
pub degree: u64,
}Expand description
An integral extension of a local field or p-adic field.
Fields
base: StringString description of the base field (e.g. “ℚ_p”).
degree: u64Degree of the extension.
Implementations
Sourceimpl IntegralExtension
impl IntegralExtension
Sourcepub fn new(base: String, degree: u64) -> Self
pub fn new(base: String, degree: u64) -> Self
Create a new IntegralExtension of the given base field.
Sourcepub fn is_totally_ramified(&self) -> bool
pub fn is_totally_ramified(&self) -> bool
Returns true if the extension is totally ramified (e = degree, f = 1).
Sourcepub fn is_unramified(&self) -> bool
pub fn is_unramified(&self) -> bool
Returns true if the extension is unramified (e = 1, f = degree).