TateAlgebra

Struct TateAlgebra 

pub struct TateAlgebra {
    pub p: u64,
    pub num_vars: usize,
}
The Tate algebra T_n = ℚ_p⟨X_1, …, X_n⟩ of strictly convergent power series.

Fields

p: u64

The prime p.

num_vars: usize

Number of variables n.

Implementations

Source

impl TateAlgebra

pub fn new(p: u64, num_vars: usize) -> Self

Construct the Tate algebra in n variables over ℚ_p.

pub fn is_noetherian(&self) -> bool

True: the Tate algebra T_n is a Noetherian ring.

pub fn is_ufd(&self) -> bool

True: T_n is a UFD.

pub fn krull_dimension(&self) -> usize

Dimension: Krull dimension of T_n is n.

pub fn polydisk_statement(&self) -> String

Statement about the Tate algebra as functions on the unit polydisk.