pub struct IrrelevantVertex {
pub problem: String,
}Expand description
Irrelevant vertex reduction rule for planar FPT algorithms.
Fields
problem: StringProblem name.
Implementations
Sourceimpl IrrelevantVertex
impl IrrelevantVertex
Sourcepub fn find_irrelevant_vertex(&self) -> String
pub fn find_irrelevant_vertex(&self) -> String
Returns a description of the irrelevant vertex identification step.
Sourcepub fn reduce_instance(&self) -> String
pub fn reduce_instance(&self) -> String
Returns a description of the instance reduction after removal.