pub struct CubicalPoint<A: Clone> {
pub dim: usize,
pub value: A,
pub face: Vec<bool>,
}Expand description
A point in a cubical path, identified by a dimension vector of booleans.
A path in dimension n is a function {0,1}^n → A.
Fields
dim: usizeThe dimension (number of interval variables)
value: AThe value at this point
face: Vec<bool>The face (coordinates in {0,1}^dim)