PegExpr

Enum PegExpr 

pub enum PegExpr {
    Char(char),
    Any,
    Seq(Box<PegExpr>, Box<PegExpr>),
    Choice(Box<PegExpr>, Box<PegExpr>),
    Star(Box<PegExpr>),
    Plus(Box<PegExpr>),
    Optional(Box<PegExpr>),
    Not(Box<PegExpr>),
    And(Box<PegExpr>),
}
A runtime PEG expression.

Variants



Char(char)

Match a literal character.



Any

Match any character.



Seq(Box<PegExpr>, Box<PegExpr>)

Sequence: e1 followed by e2.



Choice(Box<PegExpr>, Box<PegExpr>)

Ordered choice: try e1, if it fails (without consuming input) try e2.



Star(Box<PegExpr>)

Zero or more: e*



Plus(Box<PegExpr>)

One or more: e+



Optional(Box<PegExpr>)

Optional: e?



Not(Box<PegExpr>)

Negative lookahead: !e



And(Box<PegExpr>)

Positive lookahead: &e

Implementations

Source

impl PegExpr

pub fn matches(&self, input: &str, pos: usize) -> Option<usize>

Try to match the expression at position pos in input. Returns the new position if successful, or None on failure.

pub fn match_full(&self, input: &str) -> bool

Check if the expression matches the entire string.