Sigma

Struct Sigma 

pub struct Sigma<A, B> {
    pub fst: A,
    pub snd: B,
}
A dependent pair (sigma type) Σ (a : A), B(a).

At the Rust meta-level, B is represented as a plain type B rather than a type family, but conceptually this encodes dependent pairs.

Fields

fst: A

The first component (the “witness”).

snd: B

The second component (the “proof” or dependent value).

Implementations

Source

impl<A, B> Sigma<A, B>

pub fn new(fst: A, snd: B) -> Self

Construct a sigma pair.

pub fn into_parts(self) -> (A, B)

Destruct into components.

pub fn map_snd<C>(self, f: impl FnOnce(B) -> C) -> Sigma<A, C>

Map the proof component (second element) through f.

pub fn map_fst<C>(self, f: impl FnOnce(A) -> C) -> Sigma<C, B>

Map the witness (first element) through f.

pub fn elim<C>(self, f: impl FnOnce(A, B) -> C) -> C

Apply a function to both components.