SigmaVec

Struct SigmaVec 

pub struct SigmaVec<A, B> { /* private fields */ }
A vector of sigma pairs, grouping witnesses and their proofs.

Implementations

Source

impl<A, B> SigmaVec<A, B>

pub fn new() -> Self

Create an empty SigmaVec.

pub fn push(&mut self, witness: A, proof: B)

Push a new witness-proof pair.

pub fn len(&self) -> usize

Number of elements.

pub fn is_empty(&self) -> bool

Returns true if empty.

pub fn get(&self, index: usize) -> Option<&Sigma<A, B>>

Get a reference to the sigma pair at index.

pub fn iter(&self) -> impl Iterator<Item = &Sigma<A, B>>

Iterate over all sigma pairs.

pub fn witnesses(&self) -> Vec<&A>

Collect all witnesses.

pub fn proofs(&self) -> Vec<&B>

Collect all proofs.