is_constructive

Function is_constructive 

pub fn is_constructive(prop: &ConstructiveProp) -> bool
Check whether a proposition is fully constructive (intuitionistically valid).

A proposition is constructive if it avoids the law of excluded middle and double-negation elimination at top level, and all subpropositions are also constructive.