pub fn proof_to_rust(prog: &ExtractedProgram) -> StringExpand description
Generate a Rust pseudocode string representing the extracted program.
pub fn proof_to_rust(prog: &ExtractedProgram) -> StringGenerate a Rust pseudocode string representing the extracted program.