RefinementType

Struct RefinementType 

pub struct RefinementType {
    pub base: String,
    pub predicate: String,
}
A refinement type used in liquid type synthesis.

Fields

base: String

The base type (e.g., “Int”, “Bool”).

predicate: String

The refinement predicate as a string (e.g., “v > 0”).

Implementations

Source

impl RefinementType

pub fn new(base: impl Into<String>, predicate: impl Into<String>) -> Self

Construct a new refinement type.

use oxilean_std::program_synthesis::RefinementType;
let rt = RefinementType::new("Int", "v >= 0");
assert_eq!(rt.base, "Int");
pub fn is_trivial(&self) -> bool

Check whether the predicate is trivially true (empty string).

pub fn strengthen(&self, extra: impl Into<String>) -> Self

Return a strengthened type by conjoining an extra predicate.

pub fn weaken(&self, extra: impl Into<String>) -> Self

Return a weakened type by disjoining an extra predicate.