pub struct Clause {
pub literals: Vec<Literal>,
}Expand description
A clause: a disjunction of literals.
Fields
literals: Vec<Literal>The literals in the clause.
Implementations
Sourceimpl Clause
impl Clause
Sourcepub fn is_empty_clause(&self) -> bool
pub fn is_empty_clause(&self) -> bool
Returns true if this is the empty clause (contradiction).
Sourcepub fn is_tautology(&self) -> bool
pub fn is_tautology(&self) -> bool
Returns true if the clause is a tautology (contains x and ¬x).