pub struct ResolutionProof {
pub input_clauses: Vec<Vec<i32>>,
pub steps: Vec<(usize, usize, i32, Vec<i32>)>,
}Expand description
A resolution proof: a DAG of resolution steps.
Fields
input_clauses: Vec<Vec<i32>>The input clause set.
steps: Vec<(usize, usize, i32, Vec<i32>)>Resolution steps: (parent1_idx, parent2_idx, pivot_var, resolvent).
Implementations
Sourceimpl ResolutionProof
impl ResolutionProof
Sourcepub fn new(input_clauses: Vec<Vec<i32>>) -> Self
pub fn new(input_clauses: Vec<Vec<i32>>) -> Self
Create a new resolution proof from the given input clauses.
Sourcepub fn add_step(
&mut self,
p1: usize,
p2: usize,
pivot: i32,
resolvent: Vec<i32>,
)
pub fn add_step( &mut self, p1: usize, p2: usize, pivot: i32, resolvent: Vec<i32>, )
Add a resolution step.
Sourcepub fn is_refutation(&self) -> bool
pub fn is_refutation(&self) -> bool
Returns true if the proof ends with the empty clause.