pub struct GroverOracle {
pub target: usize,
}Expand description
A Grover oracle that marks a single target basis state.
The oracle implements the phase-flip O|x⟩ = -|x⟩ if x == target, else |x⟩.
Fields
target: usizeThe target basis state (integer index).
Implementations
Sourceimpl GroverOracle
impl GroverOracle
Sourcepub fn apply(&self, reg: &mut QuantumRegister)
pub fn apply(&self, reg: &mut QuantumRegister)
Apply the oracle phase-flip to the register amplitudes.
Sourcepub fn diffusion(reg: &mut QuantumRegister)
pub fn diffusion(reg: &mut QuantumRegister)
Apply the Grover diffusion operator (inversion about the mean) to the register.
Sourcepub fn run_grover(&self, n_qubits: usize, iterations: u32) -> QuantumRegister
pub fn run_grover(&self, n_qubits: usize, iterations: u32) -> QuantumRegister
Run Grover’s algorithm for iterations steps and return the register.