Auto-generated module
π€ Generated with SplitRS
FunctionsΒ
- add_
axiom - Shorthand to add an axiom to env.
- and_
prop - Build
And a b. - app
- Function application
f a. - app2
- Function application
f a b. - app3
- Function application
f a b c. - app4
- Function application
f a b c d. - array_
of Arrayapplied to a type argument.- arrow
- Build a non-dependent arrow
A -> B. - axiom_
dempster_ shafer_ belief_ ty DempsterShafer.belief : DempsterShafer β Interval Float.- axiom_
dempster_ shafer_ plausibility_ ty DempsterShafer.plausibility : DempsterShafer β Interval Float.- axiom_
fuzzy_ interval_ alpha_ cut_ ty FuzzyInterval.alpha_cut : FuzzyInterval β Float β Interval Float.- axiom_
fuzzy_ interval_ ty FuzzyInterval : Typeβ fuzzy interval for soft membership.- axiom_
gauss_ seidel_ interval_ step_ ty GaussSeidel.interval_step : Nat β Interval Float β Interval Float.- axiom_
interval_ abs_ ty Interval.abs : Interval Float β Interval Float.- axiom_
interval_ add_ ty Interval.add : Interval Float β Interval Float β Interval Floatβ Moore addition.- axiom_
interval_ contains_ ty Interval.contains : {Ξ± : Type} β [Ord Ξ±] β Interval Ξ± β Ξ± β Prop.- axiom_
interval_ correct_ rounding_ ty IntervalArithmetic.correctRounding : Propβ interval operations round outward correctly.- axiom_
interval_ cos_ ty Interval.cos : Interval Float β Interval Float.- axiom_
interval_ div_ ty Interval.div : Interval Float β Interval Float β Interval Floatβ Moore division (partial).- axiom_
interval_ exp_ ty Interval.exp : Interval Float β Interval Float.- axiom_
interval_ hi_ ty Interval.hi : {Ξ± : Type} β Interval Ξ± β Ξ±.- axiom_
interval_ hull_ ty Interval.hull : Interval Float β Interval Float β Interval Floatβ smallest enclosing interval.- axiom_
interval_ intersect_ ty Interval.intersect : Interval Float β Interval Float β Option (Interval Float).- axiom_
interval_ linear_ system_ solve_ ty IntervalLinearSystem.solve : Nat β (Interval Float) β Option (Interval Float).- axiom_
interval_ lo_ ty Interval.lo : {Ξ± : Type} β Interval Ξ± β Ξ±.- axiom_
interval_ log_ ty Interval.log : Interval Float β Option (Interval Float)β log on positive intervals.- axiom_
interval_ midpoint_ ty Interval.midpoint : Interval Float β Floatβ (lo + hi) / 2.- axiom_
interval_ mk_ ty Interval.mk : {Ξ± : Type} β Ξ± β Ξ± β Interval Ξ±β construct from lo and hi.- axiom_
interval_ mul_ ty Interval.mul : Interval Float β Interval Float β Interval Floatβ Moore multiplication.- axiom_
interval_ neg_ ty Interval.neg : Interval Float β Interval Float.- axiom_
interval_ newton_ converges_ ty IntervalNewton.converges : Propβ the interval Newton method converges quadratically.- axiom_
interval_ newton_ step_ ty IntervalNewton.step : (Float β Float) β Interval Float β Interval Float β Interval Float.- axiom_
interval_ pow_ ty Interval.pow : Interval Float β Nat β Interval Float.- axiom_
interval_ presheaf_ ty IntervalPresheaf : Type 2β intervals as a presheaf on the reals.- axiom_
interval_ scheduling_ dp_ correct_ ty IntervalScheduling.dpCorrect : Propβ DP solution correctness for WIS.- axiom_
interval_ scheduling_ optimal_ ty IntervalScheduling.optimalSchedule : List WeightedJob β List WeightedJob.- axiom_
interval_ sin_ ty Interval.sin : Interval Float β Interval Float.- axiom_
interval_ sqrt_ ty Interval.sqrt : Interval Float β Option (Interval Float).- axiom_
interval_ sub_ ty Interval.sub : Interval Float β Interval Float β Interval Floatβ Moore subtraction.- axiom_
interval_ subset_ ty Interval.subset : Interval Float β Interval Float β Prop.- axiom_
interval_ subtraction_ anticlosure_ ty IntervalArithmetic.subtraction_anticlosure : Propβ subtraction may expand intervals.- axiom_
interval_ type_ ty Interval : Type β Typeβ a closed interval type parameterized by a numeric type.- axiom_
interval_ valid_ ty Interval.valid : {Ξ± : Type} β [Ord Ξ±] β Interval Ξ± β Propβ lo β€ hi.- axiom_
interval_ valued_ probability_ ty IntervalValuedProbability : Typeβ interval-valued probability measure.- axiom_
interval_ width_ ty Interval.width : Interval Float β Floatβ hi - lo.- axiom_
ivp_ measure_ ty IntervalValuedProbability.measure : IntervalValuedProbability β Interval Float.- axiom_
krawczyk_ enclosure_ ty Krawczyk.enclosure_theorem : Propβ Krawczykβs theorem for root enclosure.- axiom_
krawczyk_ operator_ ty Krawczyk.operator : (Float β Float) β Interval Float β Interval Float.- axiom_
modal_ interval_ dual_ ty ModalInterval.dual : ModalInterval β ModalIntervalβ dual of a modal interval.- axiom_
modal_ interval_ ty ModalInterval : Typeβ modal interval arithmetic (proper and improper intervals).- axiom_
moore_ fundamental_ theorem_ ty MooreArithmetic.fundamental_theorem : Propβ fundamental theorem of interval arithmetic.- axiom_
moore_ inclusion_ monotone_ ty MooreArithmetic.inclusion_monotone : Propβ inclusion monotonicity of Moore arithmetic.- axiom_
range_ all_ iff_ ty Range.all_iff : PropβRange.all r p = true β β n β r, p n = true.- axiom_
range_ any_ iff_ ty Range.any_iff : PropβRange.any r p = true β β n β r, p n = true.- axiom_
range_ foldl_ correct_ ty Range.foldl_correct : Propβ foldl over ranges is correct with respect to List.foldl.- axiom_
segment_ tree_ query_ ty SegmentTree.query : {Ξ± : Type} β {n : Nat} β SegmentTree Ξ± n β Nat β Nat β Ξ±.- axiom_
segment_ tree_ ty SegmentTree : Type β Nat β Typeβ segment tree for interval range queries.- axiom_
segment_ tree_ update_ ty SegmentTree.update : {Ξ± : Type} β {n : Nat} β SegmentTree Ξ± n β Nat β Ξ± β SegmentTree Ξ± n.- axiom_
validated_ numerics_ enclosure_ ty ValidatedNumerics.enclosure : (Float β Float) β Interval Float β Prop.- axiom_
weighted_ job_ ty IntervalScheduling.WeightedJob : Typeβ weighted job for interval scheduling.- bool_ty
- Bool type constant.
- build_
range_ env - Build the Range type, iteration protocols, operations, and theorems.
- default_
pi - A default (explicit) Pi binder.
- eq_expr
- Build
Eq @{} ty a b. - eq_true
- Build
BEq.beq a b = Bool.true. - ge_nat
- Build
Nat.ge a b(= Nat.le b a). - iff
Iffapplied to two propositions.- implicit_
pi - An implicit Pi binder.
- inst_pi
- An instance-implicit Pi binder.
- le_nat
- Build
Nat.le a b. - list_of
Listapplied to a type argument.- lt_nat
- Build
Nat.lt a b. - mk_
array_ range - Build
Array.range n. - mk_
for_ in - Build
ForIn.forIn container init body. - mk_
iterator_ has_ next - Build
Iterator.hasNext state. - mk_
iterator_ next - Build
Iterator.next state. - mk_
list_ enum_ from - Build
List.enumFrom start l. - mk_
list_ iota - Build
List.iota n. - mk_
list_ range - Build
List.range n. - mk_
range - Build
Range.mk start stop step. - mk_
range_ all - Build
Range.all r pred. - mk_
range_ any - Build
Range.any r pred. - mk_
range_ contains - Build
Range.contains r n. - mk_
range_ foldl - Build
Range.foldl f init r. - mk_
range_ for_ m - Build
Range.forM r body. - mk_
range_ is_ empty - Build
Range.isEmpty r. - mk_
range_ of_ nat - Build
Range.ofNat start stop. - mk_
range_ single - Build
Range.single n. - mk_
range_ size - Build
Range.size r. - mk_
range_ start - Build
Range.start r. - mk_
range_ step - Build
Range.step r. - mk_
range_ stop - Build
Range.stop r. - mk_
range_ to_ list - Build
Range.toList r. - mk_
range_ with_ step - Build
Range.withStep start stop step. - mod_nat
- Build
Nat.mod a b. - monad_
of Monadapplied to a type constructor.- nat_ty
- Nat type constant.
- option_
of Optionapplied to a type argument.- prod_of
Prodapplied to two type arguments.- prop
- Prop:
Sort 0. - range_
iterator_ ty - RangeIterator type constant.
- range_
ty - Range type constant.
- register_
range_ extended - Register all extended Range/Interval axioms into the environment.
- rng_
ext_ add_ axiom - rng_
ext_ and - rng_
ext_ app - rng_
ext_ app2 - rng_
ext_ app3 - rng_
ext_ arrow - rng_
ext_ bool - rng_
ext_ eq - rng_
ext_ float - rng_
ext_ iff - rng_
ext_ interval - rng_
ext_ interval_ of - rng_
ext_ ipi - rng_
ext_ le - rng_
ext_ lt - rng_
ext_ nat - rng_
ext_ pi - rng_
ext_ prop - rng_
ext_ type1 - rng_
ext_ type2 - sub_nat
- Build
Nat.sub a b. - type1
- Type 1:
Sort 1. - type2
- Type 2:
Sort 2. - type_
to_ type Type β Type(kind of a type constructor like a monad).- unit_ty
- Unit type constant.