KrawczykSolver

Struct KrawczykSolver 

pub struct KrawczykSolver { /* private fields */ }
A simple Krawczyk-method interval root solver.

Given a function f and its derivative df, approximates a root using the Krawczyk operator K(x, X) = m - f(m)/df(X).

Implementations

Source

impl KrawczykSolver

pub fn new(max_iters: usize, tolerance: f64) -> Self

Create a new solver with given maximum iterations and tolerance.

pub fn solve<F, DF>( &self, x: FloatInterval, f: F, df: DF, ) -> Option<FloatInterval>
where F: Fn(f64) -> f64, DF: Fn(FloatInterval) -> FloatInterval,

Attempt to find a root of f in x0 using the Krawczyk operator.

f and df take the midpoint as a Float and the interval for the derivative. Returns the tightest enclosing interval if converged, otherwise None.