RMStrength

Enum RMStrength 

pub enum RMStrength {
    RCA0,
    BetweenRCA0AndWKL0,
    WKL0,
    BetweenWKL0AndACA0,
    ACA0,
    BetweenACA0AndATR0,
    ATR0,
    Pi11CA0,
    AbovePi11CA0,
    Unknown,
}
Strength classification for a combinatorial principle in the RM zoo.

Variants



RCA0

Provable in RCA₀.



BetweenRCA0AndWKL0

Strictly between RCA₀ and WKL₀.



WKL0

Equivalent to WKL₀ over RCA₀.



BetweenWKL0AndACA0

Strictly between WKL₀ and ACA₀.



ACA0

Equivalent to ACA₀ over RCA₀.



BetweenACA0AndATR0

Strictly between ACA₀ and ATR₀.



ATR0

Equivalent to ATR₀ over RCA₀.



Pi11CA0

Equivalent to Π¹_1-CA₀ over RCA₀.



AbovePi11CA0

Strictly above all Big Five (requires additional set-existence).



Unknown

Strength not yet determined.

Implementations

Source

impl RMStrength

pub fn lower_bound_system(&self) -> Option<BigFiveSystem>

Return the closest Big Five system from below (or None if below RCA₀).