pub fn build_string_env(env: &mut Environment) -> Result<(), String>Expand description
Build the standard String environment declarations.
Registers String, Char, and basic string operations as axioms in the
OxiLean kernel environment.
pub fn build_string_env(env: &mut Environment) -> Result<(), String>Build the standard String environment declarations.
Registers String, Char, and basic string operations as axioms in the
OxiLean kernel environment.