Struct Span
Source pub struct Span {
pub start: BytePos,
pub end: BytePos,
}
A half-open byte range [start, end) in a source file.
Inclusive start byte position.
Exclusive end byte position.
Create a span from raw byte offsets.
Create a zero-length span at position pos.
Returns true if this span is empty.
Merge two spans into the smallest span covering both.
Check whether this span contains pos.
Slice the source text covered by this span.
Returns None if the span is out of bounds.
Shift both endpoints by n bytes.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The equivalence relation.
Reflexivity of the equivalence.
Symmetry: if self ~ other then other ~ self.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.