pub enum ReductionStrategy {
LeftmostOutermost,
LeftmostInnermost,
RightmostOutermost,
ParallelOutermost,
Needed,
}Expand description
Represents a reduction strategy for a term rewriting system.
Variants
LeftmostOutermost
Leftmost-outermost (normal order).
LeftmostInnermost
Leftmost-innermost (applicative order).
RightmostOutermost
Rightmost-outermost.
ParallelOutermost
Parallel outermost.
Needed
Needed reduction (lazy evaluation).
Implementations
Sourceimpl ReductionStrategy
impl ReductionStrategy
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Checks if this strategy is complete (finds normal form if it exists).
Sourcepub fn normalizing_for_orthogonal(&self) -> bool
pub fn normalizing_for_orthogonal(&self) -> bool
Checks if this strategy is normalizing for orthogonal TRS.
Sourcepub fn lambda_calculus_analog(&self) -> &str
pub fn lambda_calculus_analog(&self) -> &str
Returns the corresponding lambda calculus evaluation order.