pub struct ProxRegularSet {
pub boundary_points: Vec<Vec<f64>>,
pub radius: f64,
}Expand description
Checks approximate r-prox-regularity of a finite point set by verifying that the projection is unique in an r-tube.
Fields
boundary_points: Vec<Vec<f64>>Points representing the boundary of the set.
radius: f64Prox-regularity radius.
Implementations
Sourceimpl ProxRegularSet
impl ProxRegularSet
Sourcepub fn new(boundary_points: Vec<Vec<f64>>, radius: f64) -> Self
pub fn new(boundary_points: Vec<Vec<f64>>, radius: f64) -> Self
Construct a new prox-regular set.
Sourcepub fn has_unique_projection(&self, x: &[f64]) -> bool
pub fn has_unique_projection(&self, x: &[f64]) -> bool
Check if the projection from x is unique (only one nearest neighbour).
Sourcepub fn check_prox_regular(&self, test_points: &[Vec<f64>]) -> bool
pub fn check_prox_regular(&self, test_points: &[Vec<f64>]) -> bool
Check prox-regularity: all points within the r-tube have unique projections.