pub struct SetValuedMap {
pub domain: Vec<f64>,
pub values: Vec<Vec<f64>>,
}Expand description
A set-valued map (multifunction) F: X ⇒ Y.
Fields
domain: Vec<f64>The domain points.
values: Vec<Vec<f64>>The values (each a subset of Y, represented as a Vec).
Implementations
Sourceimpl SetValuedMap
impl SetValuedMap
Sourcepub fn upper_semicontinuous(&self) -> bool
pub fn upper_semicontinuous(&self) -> bool
Returns true if the map appears upper semicontinuous at each domain point.
Sourcepub fn closed_values(&self) -> bool
pub fn closed_values(&self) -> bool
Returns whether all values sets are closed (represented as non-empty).