pub struct Subdifferential {
pub point: Vec<f64>,
}Expand description
Subdifferential of a convex or nonsmooth function at a point.
Fields
point: Vec<f64>The point at which the subdifferential is evaluated.
Implementations
Sourceimpl Subdifferential
impl Subdifferential
Sourcepub fn is_nonempty_at_interior(&self) -> bool
pub fn is_nonempty_at_interior(&self) -> bool
Returns whether the subdifferential is nonempty at interior points.
Sourcepub fn optimality_condition(&self) -> String
pub fn optimality_condition(&self) -> String
Optimality condition: 0 ∈ ∂f(x) iff x is a minimiser.