pub struct ActionFunctional {
pub lagrangian: String,
pub time_start: f64,
pub time_end: f64,
}Expand description
Action functional S[q] = ∫_{t0}^{t1} L(q, q̇, t) dt.
Fields
lagrangian: StringThe Lagrangian expression (as a string).
time_start: f64Start time t₀.
time_end: f64End time t₁.
Implementations
Sourceimpl ActionFunctional
impl ActionFunctional
Sourcepub fn new(
lagrangian: impl Into<String>,
time_start: f64,
time_end: f64,
) -> Self
pub fn new( lagrangian: impl Into<String>, time_start: f64, time_end: f64, ) -> Self
Create a new action functional with Lagrangian L on [t0, t1].
Sourcepub fn is_bounded_below(&self) -> bool
pub fn is_bounded_below(&self) -> bool
Returns true if the time interval is non-degenerate (t1 > t0).
For physical systems, the action is typically bounded below on bounded intervals.