pub struct MinimalSurfaceProblem {
pub boundary: String,
}Expand description
Minimal surface problem: find a surface of least area spanning a given boundary curve.
Fields
boundary: StringDescription of the boundary curve.
Implementations
Sourceimpl MinimalSurfaceProblem
impl MinimalSurfaceProblem
Sourcepub fn new(boundary: impl Into<String>) -> Self
pub fn new(boundary: impl Into<String>) -> Self
Create a new MinimalSurfaceProblem with the given boundary.
Sourcepub fn euler_lagrange_equation(&self) -> String
pub fn euler_lagrange_equation(&self) -> String
The Euler-Lagrange equation for minimal surfaces is the mean curvature equation H = 0. In Monge form z = u(x,y): (1+u_y²)u_xx - 2 u_x u_y u_xy + (1+u_x²)u_yy = 0.
Sourcepub fn minimal_surface_area_lower_bound(&self) -> f64
pub fn minimal_surface_area_lower_bound(&self) -> f64
Lower bound on minimal surface area: a minimal surface has area ≥ 0.