pub struct RewriteSystem<T: Clone + Eq> {
pub rules: Vec<RewriteRule<T>>,
pub strategy: RewriteStrategy,
}Expand description
A term rewriting system with a collection of rules and a reduction strategy.
Fields
rules: Vec<RewriteRule<T>>The set of rewrite rules.
strategy: RewriteStrategyThe reduction strategy to use.
Implementations
Sourceimpl<T: Clone + Eq> RewriteSystem<T>
impl<T: Clone + Eq> RewriteSystem<T>
Sourcepub fn new(strategy: RewriteStrategy) -> Self
pub fn new(strategy: RewriteStrategy) -> Self
Creates a new rewrite system with the given strategy.
Sourcepub fn add_rule(&mut self, rule: RewriteRule<T>)
pub fn add_rule(&mut self, rule: RewriteRule<T>)
Adds a rule to the system.