pub struct EffectHandler {
pub effect: String,
pub handler_fn: String,
}Expand description
An effect handler that eliminates a specific effect.
Fields
effect: StringThe name of the handled effect.
handler_fn: StringA description of the handler function.
Implementations
Sourceimpl EffectHandler
impl EffectHandler
Sourcepub fn new(effect: impl Into<String>, handler_fn: impl Into<String>) -> Self
pub fn new(effect: impl Into<String>, handler_fn: impl Into<String>) -> Self
Create a new EffectHandler.
Sourcepub fn deep_handler(&self) -> String
pub fn deep_handler(&self) -> String
A deep handler recursively handles all operations and sub-computations.
Sourcepub fn shallow_handler(&self) -> String
pub fn shallow_handler(&self) -> String
A shallow handler handles only the first operation encountered.
Sourcepub fn effect_elimination(&self) -> String
pub fn effect_elimination(&self) -> String
Handling eliminates the effect from the effect row.