pub struct AbsoluteHeight {
pub point_description: String,
pub value: f64,
}Expand description
Absolute Weil height H(P) on projective space.
Fields
point_description: StringDescription of the point.
value: f64The computed height value.
Implementations
Sourceimpl AbsoluteHeight
impl AbsoluteHeight
Sourcepub fn of_rational(p: i64, q: u64) -> Self
pub fn of_rational(p: i64, q: u64) -> Self
Compute the absolute height of a rational number p/q in lowest terms.
H(p/q) = max(|p|, |q|) for [p:q] ∈ P^1(ℚ).
Sourcepub fn of_minimal_poly(coeffs: &[i64]) -> Self
pub fn of_minimal_poly(coeffs: &[i64]) -> Self
Height of an algebraic number from its minimal polynomial coefficients.