Auto-generated module
🤖 Generated with SplitRS
Structs
- Bool
Algebra - Boolean algebra structure witnessing the laws of a Boolean algebra.
- Bool
Lattice - Boolean lattice structure: (Bool, OR=join, AND=meet, false=bot, true=top).
- Decidable
Pred - Decidable predicate: a predicate P: T -> Bool computable at runtime.
- SATInstance
- SAT instance: a propositional formula in conjunctive normal form.
- Truth
Table - A complete truth table for a 2-input boolean function.
- Truth
Table Entry - A truth table entry for a 2-input boolean function.
- XorMonoid
- XOR monoid structure: (Bool, XOR, false) is a commutative group.
Enums
- Bool
Expr - A boolean expression tree used to represent propositional formulas.
- Kleene3
Val - A simple Kleene three-valued logic evaluator.