pub struct AlphaShapeBuilder { /* private fields */ }Expand description
Builds the alpha-shape filtration of a point set. Uses the Delaunay triangulation as the underlying complex.
Implementations
Sourceimpl AlphaShapeBuilder
impl AlphaShapeBuilder
Sourcepub fn circumradius(&self, tri: &Triangle) -> f64
pub fn circumradius(&self, tri: &Triangle) -> f64
Compute the circumradius of a triangle (index triple into self.points).
Sourcepub fn critical_alphas(&self) -> Vec<f64>
pub fn critical_alphas(&self) -> Vec<f64>
Return all unique alpha values (circumradii of triangles and half-lengths of edges).
Sourcepub fn at_alpha(&self, alpha: f64) -> AlphaShapeStep
pub fn at_alpha(&self, alpha: f64) -> AlphaShapeStep
Compute the alpha shape at a specific alpha value.
Sourcepub fn filtration(&self) -> Vec<AlphaShapeStep>
pub fn filtration(&self) -> Vec<AlphaShapeStep>
Iterate over the full filtration at the critical alpha values.