pub struct FrechetDistanceApprox { /* private fields */ }Expand description
Compute the discrete Fréchet distance between two polygonal chains P and Q. Uses dynamic programming: O(mn) time and space. The discrete Fréchet distance is an upper bound on the continuous Fréchet distance.
Implementations