pub struct ConTinuousFunction {
pub is_uniformly_continuous: bool,
}Expand description
A constructive continuous function (on the Baire space or unit interval).
Fields
is_uniformly_continuous: boolWhether the function is (provably) uniformly continuous.
Implementations
Sourceimpl ConTinuousFunction
impl ConTinuousFunction
Sourcepub fn by_fan_theorem(&self) -> bool
pub fn by_fan_theorem(&self) -> bool
The Fan Theorem implies that every function on the Cantor space [2^ω] is uniformly continuous.
Sourcepub fn kleene_brouwer(&self) -> &'static str
pub fn kleene_brouwer(&self) -> &'static str
The Kleene–Brouwer ordering on well-founded trees is used to construct continuous functions from spreads.