pub struct CountableChoiceWitness {
pub choices: Vec<u64>,
}Expand description
A concrete witness for countable choice: given a sequence of non-empty sets (represented by a function that picks a canonical element), builds the choice function.
Fields
choices: Vec<u64>The chosen elements: choices[n] is the chosen element from the n-th set.
Implementations
Sourceimpl CountableChoiceWitness
impl CountableChoiceWitness
Sourcepub fn build(sel: impl Fn(usize) -> u64, count: usize) -> Self
pub fn build(sel: impl Fn(usize) -> u64, count: usize) -> Self
Build a countable choice witness from a selection function sel(n) -> element.