pub struct MinkowskiSumComputer {
pub dim: usize,
}Expand description
Computer for Minkowski sums of polytopes with additional features.
The Minkowski sum A + B = {a + b : a ∈ A, b ∈ B}. For polytopes in V-representation, this is the convex hull of all pairwise sums.
Fields
dim: usizeAmbient dimension.
Implementations
Sourceimpl MinkowskiSumComputer
impl MinkowskiSumComputer
Sourcepub fn compute(&self, a: &[Vec<f64>], b: &[Vec<f64>]) -> Vec<Vec<f64>>
pub fn compute(&self, a: &[Vec<f64>], b: &[Vec<f64>]) -> Vec<Vec<f64>>
Compute the Minkowski sum of two polytopes (V-representations). Returns the list of candidate extreme points (not yet hull-reduced).
Sourcepub fn dilate(&self, vertices: &[Vec<f64>], t: f64) -> Vec<Vec<f64>>
pub fn dilate(&self, vertices: &[Vec<f64>], t: f64) -> Vec<Vec<f64>>
Compute the dilation tK = {tx : x ∈ K} for scalar t > 0.
Sourcepub fn translate(&self, vertices: &[Vec<f64>], v: &[f64]) -> Vec<Vec<f64>>
pub fn translate(&self, vertices: &[Vec<f64>], v: &[f64]) -> Vec<Vec<f64>>
Compute the translation K + v = {x + v : x ∈ K}.