pub fn ideal_functionality_ty() -> ExprExpand description
IdealFunctionality : Type
An ideal functionality F in the UC framework: a trusted third party that receives inputs from all parties and delivers outputs. Security is defined by emulating this ideal world in the real world.