Auto-generated module
🤖 Generated with SplitRS
Structs
- AvlNode
- A node in an AVL tree.
- AvlTree
- An AVL self-balancing binary search tree.
- BTree
- B-tree properties.
- Binary
Heap - A binary min-heap backed by a
Vec. - Binary
MinHeap - Binary min-heap.
- Bloom
Filter Ds - A probabilistic Bloom filter with configurable number of bits and hash functions.
- Deque
- A double-ended queue backed by two
Vecs. - Disjoint
Set - Union-Find (Disjoint Set Union) with path compression and union by rank.
- Fenwick
Tree - Fenwick tree (Binary Indexed Tree).
- Hyper
LogLog - HyperLogLog cardinality estimator.
- Persist
Array Old - Persistent data structure (functional).
- Persist
Array V2 - Persistent
Segment Tree - Segment
Tree - A segment tree supporting range sum queries and point updates.
- Segment
Tree New - Segment tree for range queries.
- Simple
Hash Map - Disjoint hash map (open addressing).
- Skip
List - A probabilistic skip list with O(log n) expected insert and search.
- Skip
List Data - Skip
List Info - Skip list (probabilistic data structure).
- Succinct
BitVector - Succinct bit vector with O(1) rank and select.
- Treap
Data - Trie
- A trie (prefix tree) storing strings of bytes.
- Union
Find - Union-Find (Disjoint Set Union) data structure.
- VanEmde
Boas Tree - Wavelet
Tree - Wavelet tree for range queries on integer sequences.
- XFast
Trie
Type Aliases
- Persist
Array Ext - Type alias for
PersistArrayOld- a persistent array with version tracking.