pub struct SegmentTree { /* private fields */ }Expand description
A segment tree supporting range sum queries and point updates.
Both query and update run in O(log n) time.
Implementations
Sourceimpl SegmentTree
impl SegmentTree
Sourcepub fn new(values: &[i64]) -> Self
pub fn new(values: &[i64]) -> Self
Build a segment tree from a slice of values.
Time complexity: O(n).
Sourcepub fn query(&self, l: usize, r: usize) -> i64
pub fn query(&self, l: usize, r: usize) -> i64
Query the sum over the index range [l, r] (inclusive).
Returns 0 for an empty range or out-of-bounds query.
Time complexity: O(log n).