Auto-generated module
🤖 Generated with SplitRS
Traits
- Decidable
- A type whose truth value is decidable.
- Decidable
Pred - A decidable predicate
P : A → Prop. - Decidable
Rel - A decidable binary relation
R : A → A → Prop.
Functions
- build_
decidable_ env - Build the standard Decidable environment declarations.
- dcs_
ext_ bounded_ quantifiers - dcs_
ext_ constructive_ markov - dcs_
ext_ decidable_ eq_ basic - dcs_
ext_ decidable_ eq_ compound - dcs_
ext_ decidable_ typeclass - dcs_
ext_ dpll_ procedure - dcs_
ext_ lem_ boolean_ reflection - dcs_
ext_ linear_ ordering - dcs_
ext_ logical_ connective_ closure - dcs_
ext_ presburger_ arithmetic - dcs_
ext_ semi_ decidability - dcs_
ext_ undecidability_ halting - decide_
all - Decide a conjunction of a list of unit decisions.
- decide_
any - Decide a disjunction of a list of unit decisions.
- decide_
divisible - Decide whether
nis divisible byd. - decide_
ends_ with - Decide whether a string slice ends with a suffix.
- decide_
eq - Decide whether
aandbare equal for anyPartialEqtype. - decide_
even - Decide whether an integer is even.
- decide_
finite_ set_ mem - Decide membership in a
FiniteSet<T>. - decide_
interval_ non_ empty - Decide whether an interval
[lo, hi]is non-empty. - decide_
intervals_ overlap - Decide whether two intervals overlap.
- decide_
is_ none - Decide whether an
Option<T>isNone. - decide_
is_ some - Decide whether an
Option<T>isSome. - decide_
le - Decide
a ≤ bfor anyPartialOrdtype. - decide_
len - Decide whether a slice has the given length.
- decide_
lt - Decide
a < bfor anyPartialOrdtype. - decide_
mem - Decide membership of
xin a slicexs. - decide_
nat_ eq - Decide equality of two
u32values. - decide_
nat_ le - Decide
a ≤ bforu32values. - decide_
nat_ lt - Decide
a < bforu32values. - decide_
non_ empty - Decide whether a slice is non-empty.
- decide_
odd - Decide whether an integer is odd.
- decide_
option_ eq - Decide equality for
Option<T>. - decide_
range - Decide whether a
u32lies in the range[lo, hi). - decide_
slice_ eq - Decide equality for slices of
PartialEqelements. - decide_
starts_ with - Decide whether a string slice starts with a prefix.
- decide_
str_ eq - Decide equality of two string slices.
- decide_
subset - Decide whether a
FiniteSetis a subset of another. - decision_
and - Decide
P ∧ Q. - decision_
from_ result - Lift a
Result<(), E>into aDecision<()>. - decision_
implies - Decide
P → Qgiven a decision ofPand a function producing a decision ofQ. - decision_
not - Decide
¬P. - decision_
or - Decide
P ∨ Q(left-biased). - decision_
to_ result - Convert a
Decision<()>into aResult<(), String>. - run_
decisions - Run a series of named decisions and report the results.