pub struct Fin {
pub val: usize,
pub bound: usize,
}Expand description
A bounded integer value in [0, n). Host-side representation of Fin n.
Fields
val: usizeThe numeric value.
bound: usizeThe (exclusive) upper bound.
Implementations
Sourceimpl Fin
impl Fin
Sourcepub fn new(val: usize, bound: usize) -> Option<Self>
pub fn new(val: usize, bound: usize) -> Option<Self>
Create a new Fin if val < bound, otherwise None.
Sourcepub fn complement(self) -> Self
pub fn complement(self) -> Self
Return the additive inverse (complement): bound - 1 - val.
Sourcepub fn add(self, other: Self) -> Option<Self>
pub fn add(self, other: Self) -> Option<Self>
Add two Fin values with the same bound (modular).
Sourcepub fn mul(self, other: Self) -> Option<Self>
pub fn mul(self, other: Self) -> Option<Self>
Multiply two Fin values with the same bound (modular).