Auto-generated module
π€ Generated with SplitRS
FunctionsΒ
- adjacency_
matrix_ ty - AdjacencyMatrix : β {V} [Fintype V], SimpleGraph V β Matrix V V Real The adjacency matrix of a graph.
- app
- app2
- app3
- arrow
- bool_ty
- build_
graph_ theory_ env - Build the graph theory environment, registering all axioms and theorems.
- bvar
- cayley_
graph_ ty - CayleyGraph : β (G : Group) (S : Finset G), SimpleGraph G The Cayley graph Cay(G, S) with vertex set G and edges from S-generating set.
- cheeger_
constant_ ty - CheegerConstant : β {V} [Fintype V], SimpleGraph V β Real The Cheeger constant (edge expansion ratio) of a graph.
- cheeger_
inequality_ ty - CheegerInequality : β {V} [Fintype V] (G : SimpleGraph V), Ξ»β/2 β€ h(G) β€ β(2Β·dΒ·Ξ»β) The Cheeger inequality connecting spectral gap Ξ»β to edge expansion h(G).
- chromatic_
number_ ty - chromatic_number : β {V} [Fintype V], SimpleGraph V β Nat
- chromatic_
polynomial_ ty - ChromaticPolynomial : β {V} [Fintype V], SimpleGraph V β (Nat β Int) P(G, k) = number of proper k-colorings of G.
- clique_
cover_ number_ ty - CliqueCoverNumber : β {V} [Fintype V], SimpleGraph V β Nat The minimum number of cliques needed to cover all vertices.
- connectivity_
threshold_ ty - ConnectivityThreshold : Nat β Real The threshold probability p_c = ln(n)/n for G(n,p) connectivity.
- crossing_
number_ ty - CrossingNumber : β {V} [Fintype V], SimpleGraph V β Nat The crossing number cr(G): minimum crossings in any planar drawing.
- cst
- deletion_
contraction_ tutte_ ty - DeletionContractionTutte : β {V} [Fintype V] (G : SimpleGraph V) (e : Edge V), TuttePolynomial G = TuttePolynomial (Delete G e) + TuttePolynomial (Contract G e) Deletion-contraction recurrence for the Tutte polynomial.
- digraph_
adj_ ty - digraph_adj : β {V}, Digraph V β V β V β Bool
- digraph_
ty - Digraph V = { adj : V β V β Bool }
- dynamic_
graph_ ty - DynamicGraph : Type β Type A dynamic graph supporting incremental/decremental edge updates.
- edge_
connectivity_ ty - EdgeConnectivity : β {V} [Fintype V], SimpleGraph V β Nat Ξ»(G) = minimum number of edges whose removal disconnects G.
- edge_
expansion_ ty - EdgeExpansion : β {V}, SimpleGraph V β Real β Prop Cheeger constant h(G) = min over S of |βS|/min(|S|,|V\S|).
- eigenvalue_
interlacing_ ty - EigenvalueInterlacing : β {V} [Fintype V] (G H : SimpleGraph V), IsInducedSubgraph H G β InterlacesEigenvalues (Laplacian G) (Laplacian H) Cauchyβs eigenvalue interlacing theorem for graph Laplacians.
- erdos_
renyi_ graph_ ty - ErdosRenyiGraph : Nat β Real β SimpleGraph The ErdΕs-RΓ©nyi G(n,p) random graph model.
- euler_
formula_ ty - Eulerβs formula: V - E + F = 2 for connected planar graphs
- eulerian_
circuit_ thm_ ty - Eulerian circuit theorem: G has Eulerian circuit β G is connected β all degrees even
- excluded_
minor_ characterization_ ty - ExcludedMinorCharacterization : β {V}, SimpleGraph V β Type A graph class is characterized by a finite set of forbidden minors.
- four_
color_ theorem_ ty - Four Color Theorem: Ο(G) β€ 4 for any planar graph G
- fractional_
chromatic_ number_ ty - FractionalChromaticNumber : β {V} [Fintype V], SimpleGraph V β Real Ο_f(G) = inf { k/d : G has a (k:d)-coloring }.
- fully_
dynamic_ connectivity_ ty - FullyDynamicConnectivity : β {V} [Fintype V], DynamicGraph V β Prop A data structure supporting edge insertions, deletions, and connectivity queries.
- genus_
ty - Genus : β {V} [Fintype V], SimpleGraph V β Nat The genus of a graph: minimum genus of orientable surface for embedding.
- graph_
homomorphism_ ty - GraphHomomorphism : β {V W}, SimpleGraph V β SimpleGraph W β Type A graph homomorphism f : V β W preserving adjacency.
- graph_
laplacian_ ty - GraphLaplacian : β {V} [Fintype V], SimpleGraph V β Matrix V V Real L = D - A where D is degree matrix, A is adjacency matrix.
- graph_
minor_ ty - GraphMinor : β {V W}, SimpleGraph V β SimpleGraph W β Prop H is a minor of G if H can be obtained from a subgraph of G by contracting edges.
- graphon_
cut_ distance_ ty - GraphonCutDistance : Graphon β Graphon β Real The cut distance between two graphons.
- graphon_
ty - Graphon : Type A graphon is a symmetric measurable function W : [0,1]Β² β [0,1].
- halls_
theorem_ ty - Hallβs theorem: bipartite graph G=(AβͺB, E) has perfect matching β for all S β A, |N(S)| β₯ |S|
- homomorphism_
duality_ ty - HomomorphismDuality : β {V W} (H : SimpleGraph V) (G : SimpleGraph W), Β¬ (Hom H G) β β (D : Digraph), DualObstruction D G Homomorphism duality: absence of H-homomorphism characterized by dual.
- hypergraph_
coloring_ ty - HypergraphColoring : β {V}, Hypergraph V β Nat β Prop A proper k-coloring of a hypergraph: each hyperedge has at least 2 colors.
- hypergraph_
turan_ ty - HypergraphTuran : β (r k n : Nat), TuranDensity r k n TurΓ‘n-type density results for hypergraphs.
- hypergraph_
ty - Hypergraph : Type β Type A hypergraph on vertex type V: a collection of hyperedges (subsets of V).
- ihara_
zeta_ function_ ty - IharaZetaFunction : β {V} [Fintype V], SimpleGraph V β (Complex β Complex) The Ihara zeta function Z_G(u) = β_p (1 - u^{|p|})^{-1} over prime cycles p.
- impl_pi
- incremental_
connectivity_ ty - IncrementalConnectivity : β {V} [Fintype V], DynamicGraph V β Prop An online connectivity structure supporting only edge insertions.
- is_
bipartite_ ty - IsBipartite : β {V}, SimpleGraph V β Prop
- is_
eulerian_ ty - IsEulerian : β {V}, SimpleGraph V β Prop A graph has an Eulerian circuit iff every vertex has even degree and graph is connected
- is_
hamiltonian_ ty - IsHamiltonian : β {V}, SimpleGraph V β Prop A graph has a Hamiltonian cycle visiting each vertex exactly once
- is_
perfect_ graph_ ty - IsPerfectGraph : β {V}, SimpleGraph V β Prop A graph is perfect if Ο(H) = Ο(H) for every induced subgraph H.
- is_
perfect_ matching_ ty - IsPerfectMatching : β {V} [Fintype V], SimpleGraph V β Matching β Prop
- is_
planar_ ty - IsPlanar : β {V}, SimpleGraph V β Prop
- is_
tree_ ty - IsTree G β Connected G β acyclic G
- kruskal_
mst - Minimum spanning tree via Kruskalβs algorithm (weighted undirected graph).
- kuratowski_
theorem_ ty - Kuratowskiβs theorem: G is planar β G has no Kβ or Kββ subdivision
- lovasz_
theta_ ty - LovaszThetaFunction : β {V} [Fintype V], SimpleGraph V β Real The LovΓ‘sz theta function Ο(G), sandwiched between Ο(G) and Ο(GΜ ).
- matching_
polynomial_ ty - MatchingPolynomial : β {V} [Fintype V], SimpleGraph V β (Real β Real) ΞΌ(G, x) = β_k (-1)^k m_k(G) x^{n-2k} where m_k = number of k-matchings.
- matching_
ty - Matching G = Set of independent edges
- max_
flow - Max-flow via Ford-Fulkerson with BFS (Edmonds-Karp).
- max_
flow_ min_ cut_ ty - MaxFlowMinCut : β (n : Nat) (s t : Nat) (cap : Nat β Nat β Real), MaxFlow n s t cap = MinCutCapacity n s t cap Max-flow min-cut theorem for real-valued capacities.
- mengers_
theorem_ ty - MengersThm : β {V} [Fintype V] (G : SimpleGraph V) (s t : V), MaxDisjointPaths G s t = MinVertexCut G s t Mengerβs theorem: max number of vertex-disjoint s-t paths = min vertex cut size.
- nat_ty
- pathwidth_
ty - Pathwidth : β {V} [Fintype V], SimpleGraph V β Nat pw(G) = min over path decompositions of (max bag size - 1).
- phase_
transition_ ty - PhaseTransition : β (n : Nat) (p : Real), p > 1/n β GiantComponentExists (ErdosRenyi n p) Phase transition at p = 1/n: a giant component emerges.
- pi
- prop
- real_ty
- robertson_
seymour_ wqo_ ty - RobertsonSeymourWQO : β {V} (seq : Nat β SimpleGraph V), β i j, i < j β Minor (seq i) (seq j) The Robertson-Seymour theorem: graphs are well-quasi-ordered under the minor relation.
- semi_
streaming_ sketch_ ty - SemiStreamingSketch : β {V} [Fintype V], SimpleGraph V β Type A semi-streaming sketch using O(n Β· polylog n) space for n = |V|.
- simple_
graph_ adj_ ty - SimpleGraph.adj : β {V}, SimpleGraph V β V β V β Prop
- simple_
graph_ connected_ ty - SimpleGraph.Connected : β {V}, SimpleGraph V β Prop
- simple_
graph_ degree_ ty - SimpleGraph.degree : β {V} [Fintype V] [DecidableEq V], SimpleGraph V β V β Nat
- simple_
graph_ ty - SimpleGraph V = { adj : V β V β Prop // sym, irrefl }
- sketched_
connectivity_ ty - SketchedConnectivity : β {V} [Fintype V], SemiStreamingSketch β Prop Determine connectivity from a semi-streaming sketch.
- spectral_
gap_ ty - SpectralGap : β {V} [Fintype V], SimpleGraph V β Real The spectral gap Ξ»β = second smallest eigenvalue of the normalized Laplacian.
- strong_
perfect_ graph_ thm_ ty - StrongPerfectGraphThm : β {V} (G : SimpleGraph V), IsPerfect G β (NoOddHole G β NoOddAntihole G) The strong perfect graph theorem (Chudnovsky-Robertson-Seymour-Thomas 2006).
- strongly_
regular_ graph_ ty - StronglyRegularGraph : β {V} [Fintype V] (G : SimpleGraph V) (k Ξ» ΞΌ : Nat), Prop srg(n, k, Ξ», ΞΌ): k-regular, adjacent pairs have Ξ» common neighbors, non-adjacent pairs have ΞΌ common neighbors.
- sunflower_
lemma_ ty - SunflowerLemma : β (p k : Nat) (F : Finset (Finset Nat)), |F| > (p-1)^k Β· k! β β sunflower of size p in F ErdΕs-Ko-Rado sunflower lemma for set families.
- szemeredi_
regularity_ ty - SzemerediRegularity : β {V} [Fintype V] (G : SimpleGraph V) (Ξ΅ : Real), β partition, Ξ΅-regular and |partition| β€ M(Ξ΅) SzemerΓ©di regularity lemma: every graph has an Ξ΅-regular partition.
- tree_
decomposition_ ty - TreeDecomposition : β {V}, SimpleGraph V β Type A tree decomposition of G: a tree T with bags B(t) β V covering edges.
- treewidth_
duality_ ty - TreewidthDuality : β {V} [Fintype V] (G : SimpleGraph V) (k : Nat), Treewidth G β€ k β Β¬ HasBranchDecompositionObstruction G k Treewidth duality via brambles/haven obstructions.
- treewidth_
ty - Treewidth : β {V} [Fintype V], SimpleGraph V β Nat tw(G) = min over tree decompositions of (max bag size - 1).
- tutte_
polynomial_ ty - TuttePolynomial : β {V} [Fintype V], SimpleGraph V β (Real β Real β Real) T(G; x, y) = universal graph polynomial encoding many graph invariants.
- type0
- vertex_
connectivity_ ty - VertexConnectivity : β {V} [Fintype V], SimpleGraph V β Nat ΞΊ(G) = minimum number of vertices whose removal disconnects G.
- vertex_
expansion_ ty - VertexExpansion : β {V}, SimpleGraph V β Real β Prop h-vertex expander: for all S with |S| β€ |V|/2, |N(S)| β₯ hΒ·|S|.
- wagner_
theorem_ ty - WagnerThm : β {V} (G : SimpleGraph V), IsPlanar G β NoK5Minor G β NoK33Minor G Wagnerβs theorem: G is planar iff G has no Kβ or Kβ,β minor.
- walk_ty
- Walk G u v = path from u to v in G (list of adjacent vertices)