Auto-generated module
🤖 Generated with SplitRS
Structs
- Assoc
Map - A simple association list map.
- BiMap
- A bidirectional map where both keys and values are unique.
- FreqMap
- A map counting how many times each key has been seen.
- Frozen
Hash Map - Immutable frozen snapshot of a HashMap.
- Hash
MapDiff - Represents the structural difference between two HashMaps.
- Hash
MapMonoid - HashMap viewed as a monoid under union (left-biased merge).
- Indexed
Map - A vector-backed map where keys are dense integers 0..n.
- Interval
Entry - An entry in an interval map.
- Interval
Map - A simple interval map for ordered key types.
- LRUCache
Hm - Simple LRU cache backed by a HashMap.
- LruMap
- A map with LRU (least-recently-used) eviction policy.
- Multi
Map - A map that associates each key with a list of values.
- Multi
MapHm - Multi-map: each key maps to a list of values.
- Persistent
Map - An immutable persistent map based on a binary search tree.
- Stack
Map - A map supporting scoped bindings with push/pop semantics.