pub struct Capability {
pub level: u32,
pub description: String,
}Expand description
A capability token representing a permission level for IO operations.
Fields
level: u32The permission level (higher = more privileged).
description: StringHuman-readable description.
Implementations
Sourceimpl Capability
impl Capability
Sourcepub fn read_write() -> Self
pub fn read_write() -> Self
Read-write capability.
Sourcepub fn is_sufficient_for(&self, required: u32) -> bool
pub fn is_sufficient_for(&self, required: u32) -> bool
Check if this capability is sufficient for the required level.
Sourcepub fn attenuate(&self, max_level: u32) -> Capability
pub fn attenuate(&self, max_level: u32) -> Capability
Attenuate (reduce) the capability to a lower level.