pub struct Quantales {
pub quantale: String,
}Expand description
A quantale: a complete lattice with an associative binary operation that distributes over arbitrary joins. Quantales model substructural logics.
Fields
quantale: StringName of the quantale.
Implementations
Sourceimpl Quantales
impl Quantales
Sourcepub fn is_linear_category(&self) -> bool
pub fn is_linear_category(&self) -> bool
Check if this quantale is a model of linear logic (a *-autonomous quantale).
Sourcepub fn star_autonomous(&self) -> String
pub fn star_autonomous(&self) -> String
Check if this is a *-autonomous (star-autonomous) category.
A *-autonomous category is a symmetric monoidal category with a dualizing object,
giving models of classical linear logic (MLL).
Sourcepub fn free_star_autonomous(atoms: &[&str]) -> Self
pub fn free_star_autonomous(atoms: &[&str]) -> Self
The free *-autonomous category on a set of atoms.
Sourcepub fn phase_space_quantale(monoid: &str) -> Self
pub fn phase_space_quantale(monoid: &str) -> Self
The phase space quantale over a monoid.
Sourcepub fn chu_construction(&self, k: &str) -> String
pub fn chu_construction(&self, k: &str) -> String
The Chu construction: a way to build *-autonomous categories.
Sourcepub fn dualizing_object(&self) -> String
pub fn dualizing_object(&self) -> String
The dualizing object (bottom element in MLL models).