pub enum ModalSystem {
K,
T,
S4,
S5,
D,
KD45,
GL,
B,
}Expand description
Identifies a normal modal logic by its axiom schema name.
Variants
K
K: the minimal normal modal logic
T
T (= M): K + Axiom T (reflexivity)
S4
S4: T + Axiom 4 (transitivity)
S5
S5: S4 + Axiom B (symmetry)
D
D: K + Axiom D (seriality, deontic)
KD45
KD45: D + Axiom 4 + Axiom 5 (doxastic belief)
GL
GL: K + Axiom Löb (provability)
B
B: K + T + B (Brouwer)
Implementations
Sourceimpl ModalSystem
impl ModalSystem
Sourcepub fn frame_validates(&self, frame: &KripkeFrame, rel: usize) -> bool
pub fn frame_validates(&self, frame: &KripkeFrame, rel: usize) -> bool
Check whether the given frame satisfies the characteristic frame condition.