Auto-generated module
π€ Generated with SplitRS
FunctionsΒ
- abstract_
domain_ ty - AbstractDomain: predicate abstraction / interval / octagon domain
- abstract_
states_ ty - abstract_states: map concrete states to abstract domain
- abstract_
transformer_ ty - AbstractTransformer: postΟ
- ag_
decomposition_ ty - ag_decomposition: decompose a verification task using A-G reasoning ag_decomposition : KripkeStructure β AssumeGuaranteeContract β Bool
- alc_
concept_ ty - ALC: the description logic ALC (attribute language with complement)
- alternating_
turing_ machine_ ty - AlternatingTuringMachine: ATM used in alternation-based ΞΌ-calculus model checking
- ample_
set_ ty - AmpleSet: an ample set satisfying C0βC3 for POR AmpleSet : KripkeStructure β State β Set (State β State) β Prop
- app
- app2
- app3
- arrow
- assume_
guarantee_ contract_ ty - AssumeGuaranteeContract: an AG specification (A, G)
- atomic_
proposition_ ty - AtomicProposition: boolean-valued proposition on states
- bdd_
manager_ ty - BDDManager: unique table + apply cache
- bdd_ty
- BDD: Binary Decision Diagram node
- bool_ty
- bounded_
mc_ query_ ty - BoundedMCQuery: a bounded model checking problem (BMC) BoundedMCQuery : KripkeStructure β LtlFormula β Nat β Bool
- buchi_
automaton_ ty - BuchiAutomaton: (Q, Ξ£, Ξ΄, q_0, F) Ο-automaton
- build_
env - Register all model checking axioms into the kernel environment.
- bvar
- cegar_
ty - CounterExampleGuidedRefinement: CEGAR loop
- check_
ctl_ ty - check_ctl: check whether K β¨ Ο (CTL)
- check_
feasibility_ ty - check_feasibility: determine if a counterexample is spurious
- check_
ltl_ ty - check_ltl: check whether K β¨ Ο (LTL)
- check_
mu_ ty - check_mu: model check a ΞΌ-calculus formula check_mu : KripkeStructure β MuFormula β Bool
- check_
pctl_ ty - check_pctl: check whether M β¨ Ο (PCTL) check_pctl : ProbabilisticKripke β PCTLFormula β Bool
- check_
psl_ ty - check_psl: check a PSL formula against a Kripke structure check_psl : KripkeStructure β PSLFormula β Bool
- check_
pushdown_ ltl_ ty - check_pushdown_ltl: model check a pushdown system against an LTL formula check_pushdown_ltl : PushdownSystem β LtlFormula β Bool
- check_
tctl_ ty - check_tctl: verify a timed CTL formula over a timed automaton check_tctl : TimedAutomaton β TCTLFormula β Bool
- compute_
scc_ ty - compute_scc: Tarjanβs SCC decomposition
- context_
free_ ltl_ ty - ContextFreeLTL: an LTL formula interpreted over pushdown system runs
- counter_
example_ ty - CounterExample: trace witnessing formula violation
- craig_
interpolant_ ty - CraigInterpolant: a formula I with A β¨ I and I β B unsatisfiable CraigInterpolant : LtlFormula β LtlFormula β LtlFormula β Prop
- cst
- ctl_
formula_ ty - CTL formula type
- ctl_
model_ checker_ ty - CtlModelChecker: fixpoint computation for CTL
- ctl_
star_ formula_ ty - CTL* formula type
- find_
counterexample_ ty - find_counterexample: produce a counterexample trace if formula fails
- flow_
condition_ ty - FlowCondition: ODE describing continuous evolution in a mode FlowCondition : Type β Prop
- guard_
region_ ty - GuardRegion: a polyhedral region enabling a discrete transition GuardRegion : Type β Prop
- hors_
model_ checking_ ty - HORSModelChecking: model check a HORS against an MSO property HORSModelChecking : HigherOrderRecursionScheme β MuFormula β Bool
- hors_ty
- HigherOrderRecursionScheme: a HORS defining a tree language
- hybrid_
automaton_ ty - HybridAutomaton: automaton with continuous flow conditions
- hybrid_
reachability_ ty - HybridReachability: reachable set of a hybrid system HybridReachability : HybridAutomaton β Set Type
- image_
ty - image: compute the forward image of a set of states
- impl_pi
- interface_
verification_ ty - interface_verification: check compatibility of component interfaces interface_verification : List AssumeGuaranteeContract β Bool
- is_
connected_ ty - is_connected: every state is reachable from some initial state
- k_
induction_ check_ ty - k_induction_check: run k-induction for LTL safety properties k_induction_check : KripkeStructure β LtlFormula β Nat β KInductionResult
- k_
induction_ result_ ty - KInductionResult: result of a k-induction proof step
- kripke_
structure_ ty - KripkeStructure: (S, S_0, R, L)
- lazy_
cegar_ ty - lazy_cegar: CEGAR with lazy abstraction refinement lazy_cegar : KripkeStructure β LtlFormula β Bool
- ltl_
formula_ ty - LTL formula type
- ltl_
is_ fairness_ ty - ltl_is_fairness: Ο is a fairness constraint
- ltl_
is_ liveness_ ty - ltl_is_liveness: Ο is a liveness property
- ltl_
is_ safety_ ty - ltl_is_safety: Ο is a safety property
- ltl_
model_ checker_ ty - LtlModelChecker: automaton-theoretic LTL checking
- mazurkiewicz_
trace_ ty - MazurkiewiczTrace: an equivalence class of runs under independence
- mu_
calculus_ parity_ reduction_ ty - mu_calculus_parity_reduction: reduction of ΞΌ-calc. to parity games mu_calculus_parity_reduction : MuFormula β ParityGame
- mu_
fixpoint_ ty - mu_fixpoint: the least fixpoint operator ΞΌX.Ο(X) mu_fixpoint : (State β Prop) β (State β Prop)
- mu_
formula_ ty - MuFormula: a ΞΌ-calculus formula type
- nat_ty
- nu_
fixpoint_ ty - nu_fixpoint: the greatest fixpoint operator Ξ½X.Ο(X) nu_fixpoint : (State β Prop) β (State β Prop)
- parity_
condition_ ty - ParityCondition: Ο-winning condition: the highest priority seen inf-often is even ParityCondition : (Nat β Bool) β Prop
- parity_
game_ ty - ParityGame: a game graph with priority function
- parity_
game_ winner_ ty - parity_game_winner: which player wins from a given vertex? parity_game_winner : ParityGame β Nat β Bool
- pctl_
formula_ ty - PCTLFormula: a PCTL (probabilistic CTL) formula type
- persistent_
set_ ty - PersistentSet: a persistent set for partial order reduction PersistentSet : KripkeStructure β State β Set (State β State) β Prop
- pi
- por_
reduction_ ty - por_reduction: apply partial order reduction to a Kripke structure por_reduction : KripkeStructure β KripkeStructure
- pre_
image_ ty - pre_image: compute the backward image of a set of states
- probabilistic_
kripke_ ty - ProbabilisticKripke: a Markov Decision Process / Markov chain
- prop
- psl_
formula_ ty - PSLFormula: a PSL (Property Specification Language) formula
- pushdown_
reachability_ ty - pushdown_reachability: backwards reachability in a pushdown system pushdown_reachability : PushdownSystem β Set State
- pushdown_
system_ ty - PushdownSystem: a recursive program modeled as a pushdown automaton
- reachability_
probability_ ty - reachability_probability: P[reach(T) from s] in a Markov chain reachability_probability : ProbabilisticKripke β State β Set State β Real
- reachable_
states_ ty - reachable_states: the set of states reachable from initial states
- refine_
abstraction_ ty - refine_abstraction: refine abstract domain using a spurious counterexample
- sat_
solver_ ty - SatSolver: a SAT/SMT oracle used in bounded model checking
- spurious_
counterexample_ ty - SpuriousCounterexample: infeasible concrete path
- state_
label_ ty - StateLabel: set of atomic propositions true in a state
- sva_
formula_ ty - SVAFormula: a SystemVerilog assertion formula
- symbolic_
transition_ relation_ ty - SymbolicTransitionRelation: T(s,sβ) as BDD
- tctl_
formula_ ty - TCTLFormula: a timed CTL formula
- temporal_
logic_ pattern_ ty - TemporalLogicPattern: a reusable specification pattern (Dwyer patterns)
- timed_
automaton_ ty - TimedAutomaton: automaton with clock variables
- type0
- zielonka_
solver_ ty - ZielonkaSolver: Zielonkaβs recursive parity game algorithm ZielonkaSolver : ParityGame β Bool
- zone_
graph_ ty - ZoneGraph: zone-based abstract state space for timed systems
- zone_
reachability_ ty - zone_reachability: compute the reachable zone graph of a timed automaton zone_reachability : TimedAutomaton β ZoneGraph