pub struct HyperfiniteProb {
pub size: usize,
}Expand description
A simplified Loeb probability space on a finite hyperfinite set {0, …, N-1}.
The internal probability of a set A is |A|/N. The Loeb probability is the standard part: st(|A|/N) = |A|/N for finite N.
Fields
size: usizeThe “infinite” (but computationally finite) size N.
Implementations
Sourceimpl HyperfiniteProb
impl HyperfiniteProb
Sourcepub fn internal_prob(&self, set: &[usize]) -> f64
pub fn internal_prob(&self, set: &[usize]) -> f64
Internal probability of a set given by a list of indices.
Sourcepub fn loeb_prob(&self, set: &[usize]) -> f64
pub fn loeb_prob(&self, set: &[usize]) -> f64
Loeb probability = standard part of internal probability (same for finite sizes).
Sourcepub fn loeb_independent(&self, a: &[usize], b: &[usize]) -> bool
pub fn loeb_independent(&self, a: &[usize], b: &[usize]) -> bool
Check if two events are “independent” under Loeb measure.