pub struct Permutation {
pub perm: Vec<usize>,
}Expand description
A permutation of indices 0..n.
Fields
perm: Vec<usize>Implementations
Sourceimpl Permutation
impl Permutation
Sourcepub fn from_sort_order<T: Ord>(v: &[T]) -> Self
pub fn from_sort_order<T: Ord>(v: &[T]) -> Self
Create a permutation from a sorted-order vector.
perm[i] = j means that position i in the sorted order
came from position j in the original.
Sourcepub fn apply<T: Clone>(&self, v: &[T]) -> Vec<T>
pub fn apply<T: Clone>(&self, v: &[T]) -> Vec<T>
Apply the permutation to a slice, returning a new Vec.
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Check if this is the identity permutation.