pub struct IwasawaModule {
pub algebra: IwasawaAlgebra,
pub rank: usize,
pub torsion: String,
}Expand description
A finitely generated module over the Iwasawa algebra.
Fields
algebra: IwasawaAlgebraThe Iwasawa algebra acting on this module.
rank: usizeThe rank of the free part of the module.
torsion: StringInformal description of the torsion submodule.
Implementations
Sourceimpl IwasawaModule
impl IwasawaModule
Sourcepub fn new(algebra: IwasawaAlgebra, rank: usize, torsion: String) -> Self
pub fn new(algebra: IwasawaAlgebra, rank: usize, torsion: String) -> Self
Construct an Iwasawa module with given algebra, rank, and torsion description.
Sourcepub fn structural_theorem_statement(&self) -> String
pub fn structural_theorem_statement(&self) -> String
Return a string describing the structure theorem for finitely generated Λ-modules.