pub struct TateAlgebra {
pub p: u64,
pub num_vars: usize,
}Expand description
The Tate algebra T_n = ℚ_p⟨X_1, …, X_n⟩ of strictly convergent power series.
Fields
p: u64The prime p.
num_vars: usizeNumber of variables n.
Implementations
Sourceimpl TateAlgebra
impl TateAlgebra
Sourcepub fn new(p: u64, num_vars: usize) -> Self
pub fn new(p: u64, num_vars: usize) -> Self
Construct the Tate algebra in n variables over ℚ_p.
Sourcepub fn is_noetherian(&self) -> bool
pub fn is_noetherian(&self) -> bool
True: the Tate algebra T_n is a Noetherian ring.
Sourcepub fn krull_dimension(&self) -> usize
pub fn krull_dimension(&self) -> usize
Dimension: Krull dimension of T_n is n.
Sourcepub fn polydisk_statement(&self) -> String
pub fn polydisk_statement(&self) -> String
Statement about the Tate algebra as functions on the unit polydisk.