pub struct Sigma<A, B> {
pub fst: A,
pub snd: B,
}Expand description
A dependent pair (sigma type) Σ (a : A), B(a).
At the Rust meta-level, B is represented as a plain type B rather
than a type family, but conceptually this encodes dependent pairs.
Fields
fst: AThe first component (the “witness”).
snd: BThe second component (the “proof” or dependent value).
Implementations
Sourceimpl<A, B> Sigma<A, B>
impl<A, B> Sigma<A, B>