pub enum ComplexityBound {
Constant,
Linear,
Polynomial(u32),
Exponential,
NonElementary,
}Expand description
A polynomial or exponential complexity bound extracted from a proof.
Variants
Constant
Constant O(1).
Linear
Linear O(n).
Polynomial(u32)
Polynomial O(n^k) for given k.
Exponential
Exponential O(2^n).
NonElementary
Non-elementary.
Implementations
Sourceimpl ComplexityBound
impl ComplexityBound
Sourcepub fn is_polynomial(&self) -> bool
pub fn is_polynomial(&self) -> bool
Returns true if the bound is at most polynomial.