pub fn surface_code_distance_ty() -> Expr
SurfaceCodeDistance : ∀ d : Nat, Prop The surface code with parameter d has code distance d, i.e., the minimum weight of any undetectable logical error is d.
SurfaceCodeDistance : ∀ d : Nat, Prop