pub struct SignExpansionEncoder { /* private fields */ }Expand description
Encoder and decoder for surreal sign-expansion sequences.
The sign expansion of a surreal number x is a sequence of +/- signs obtained by walking the surreal tree from the root (0) to x:
-
- means “x is to the right of the current node” (x > current)
-
- means “x is to the left of the current node” (x < current)
Implementations
Sourceimpl SignExpansionEncoder
impl SignExpansionEncoder
Sourcepub fn from_fin_surreal(x: &FinSurreal) -> Self
pub fn from_fin_surreal(x: &FinSurreal) -> Self
Encode a dyadic rational as its sign expansion.
Sourcepub fn decode(&self) -> FinSurreal
pub fn decode(&self) -> FinSurreal
Decode the sign sequence back to a dyadic rational approximation.